@@ -6,15 +6,15 @@ from .config import IMAGES_DIR
 
 
 def download_image(url, filename):
-    """Pobiera obraz z podanego URL i zapisuje go w katalogu obrazów."""
+    """Downloads an image from the given URL and saves it to the images directory."""
     IMAGES_DIR.mkdir(parents=True, exist_ok=True)
     image_path = IMAGES_DIR / filename
 
     if image_path.exists():
-        print(f"Obraz {filename} już istnieje, pomijam pobieranie.")
+        print(f"Image {filename} already exists, skipping download.")
         return str(image_path)
 
-    print(f"Pobieranie obrazu z {url}...")
+    print(f"Downloading image from {url}...")
     try:
         subprocess.run(
             ["wget", "-O", str(image_path), url],
@@ -22,21 +22,21 @@ def download_image(url, filename):
             capture_output=True,
             text=True
         )
-        print(f"✅ Obraz {filename} został pobrany.")
+        print(f"✅ Image {filename} downloaded successfully.")
         return str(image_path)
     except subprocess.CalledProcessError as e:
-        raise RuntimeError(f"Błąd podczas pobierania obrazu: {e.stderr}")
+        raise RuntimeError(f"Error downloading image: {e.stderr}")
 
 
 def get_image_path(os_name, config):
-    """Zwraca ścieżkę do obrazu OS, pobierając go jeśli nie istnieje."""
+    """Returns the path to the OS image, downloading it if it doesn't exist."""
     if os_name not in config["images"]:
-        raise ValueError(f"Nieznany system operacyjny: {os_name}")
+        raise ValueError(f"Unknown operating system: {os_name}")
 
     image_config = config["images"][os_name]
     url = image_config["url"]
 
-    # Wyodrębnij nazwę pliku z URL
+    # Extract filename from URL
     parsed_url = urlparse(url)
     filename = os.path.basename(parsed_url.path)
     if not filename.endswith(('.qcow2', '.img')):
